Public Function Reference
=========================

.. autosummary::
   :toctree: generated


Surface Calculation
-------------------

.. autofunction:: surf.load_tsdata

.. autofunction:: surf.find_omega_surfs

Grid interpretation
-------------------

.. autofunction:: grid.build_nemo_hgrid

.. autofunction:: grid.load_hgriddata

.. autofunction:: grid.load_zgriddata

